@@ -1,3 +1,4 @@
+# Copyright (c) 2008 - 2021, Ilan Schnell; All Rights Reserved
 """
 This package defines an object type which can efficiently represent
 a bitarray.  Bitarrays are sequence types and behave very much like lists.
@@ -10,12 +11,12 @@ Author: Ilan Schnell
 """
 from __future__ import absolute_import
 
-from bitarray._bitarray import (bitarray, bitdiff, _sysinfo,
+from bitarray._bitarray import (bitarray, decodetree, _sysinfo,
                                 get_default_endian, _set_default_endian,
                                 __version__)
 
 
-__all__ = ['bitarray', 'frozenbitarray', '__version__']
+__all__ = ['bitarray', 'frozenbitarray', 'decodetree', '__version__']
 
 
 class frozenbitarray(bitarray):
@@ -32,7 +33,7 @@ as a dictionary key.
     def __hash__(self):
         "Return hash(self)."
         if getattr(self, '_hash', None) is None:
-            self._hash = hash((self.length(), self.tobytes()))
+            self._hash = hash((len(self), self.tobytes()))
         return self._hash
 
     def __delitem__(self, *args, **kwargs):
